chrome.runtime.onMessage.addListener(async (message, sender, sendResponse) => {
  if (message.action === 'parseHTML') {
    const parser = new DOMParser();
    const doc = parser.parseFromString(message.html, 'text/html');
    
    // Find only unread alerts
    const alertElements = doc.querySelectorAll('.alertToggler.is-unread, .js-alert.is-unread, .alert.is-unread');
    console.log('Found unread alerts:', alertElements.length);
    
    const alerts = Array.from(alertElements).map(alert => {
      // Log the full HTML structure
      console.log('=== Alert HTML Structure ===');
      console.log(alert.outerHTML);
      
      // Get all possible text elements
      const alertText = alert.querySelector('.alertToggler-text, .js-alert-text, .alert-message');
      const contentText = alert.querySelector('.contentRow-main');
      const titleText = alert.querySelector('.contentRow-title');
      const snippetText = alert.querySelector('.contentRow-snippet');
      
      // Log all found text elements
      console.log('=== Alert Text Elements ===');
      console.log('Alert Text:', alertText?.textContent);
      console.log('Content Text:', contentText?.textContent);
      console.log('Title Text:', titleText?.textContent);
      console.log('Snippet Text:', snippetText?.textContent);
      
      // Get the timestamp
      const timeElement = alert.querySelector('.u-dt');
      const timestamp = timeElement ? timeElement.textContent.trim() : '';
      
      // Try to find the link in different possible locations
      const links = alert.querySelectorAll('a');
      console.log('=== Alert Links ===');
      links.forEach(link => {
        console.log('Link:', {
          href: link.href,
          text: link.textContent.trim()
        });
      });
      
      const link = Array.from(links).find(l => {
        const href = l.href || '';
        return !href.includes('/members/') && 
               !href.includes('/account/alerts') &&
               !href.includes('mark-read') &&
               !href.includes('alert-');
      });
      
      let url = 'https://www.prog.co.il/account/alerts';
      if (link) {
        const href = link.getAttribute('href');
        url = href.startsWith('http') ? href : `https://www.prog.co.il${href.startsWith('/') ? '' : '/'}${href}`;
      }
      
      // Try to get the full content by combining different elements
      const allTexts = [
        alertText?.textContent.trim(),
        contentText?.textContent.trim(),
        titleText?.textContent.trim(),
        snippetText?.textContent.trim()
      ].filter(Boolean);
      
      const content = allTexts.join(' ') || alert.textContent.trim();
      console.log('=== Final Content ===');
      console.log(content);
      
      // Split the content into parts for formatting
      const parts = content.match(/^(.+?) הגיב\/ה לנושא (.+?)(?:\. (.+))?$/);
      
      let formattedContent = content;
      if (parts) {
        const [_, username, topic, rest] = parts;
        // שם המשתמש והנושא מודגשים, שאר הטקסט רגיל
        formattedContent = `<span class="username">${username}</span> הגיב/ה לנושא <span class="topic">${topic}</span>${rest ? `. ${rest}` : ''}<div class="time">${timestamp}</div>`;
      }
      
      console.log('=== Formatted Content ===');
      console.log(formattedContent);
      console.log('========================');
      
      const alertId = alert.getAttribute('data-alert-id') || 
                     alert.getAttribute('data-content-id') || 
                     alert.id || 
                     Math.random().toString(36).substr(2, 9);
      
      return {
        id: alertId,
        content: formattedContent,
        url: url
      };
    });
    
    sendResponse({ alerts });
    return true;
  }
});

// Listen for messages from the service worker
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.target === 'offscreen' && message.type === 'play-sound') {
        const audio = new Audio(message.soundUrl);
        audio.volume = 1.0;
        
        audio.play().then(() => {
            sendResponse({ success: true });
        }).catch(error => {
            console.error('Error playing sound:', error);
            sendResponse({ success: false, error: error.message });
        });
    } else if (message.target === 'offscreen' && message.action === 'parseHTML') {
        try {
            const parser = new DOMParser();
            const doc = parser.parseFromString(message.html, 'text/html');
            const alertElements = doc.querySelectorAll('.alertsScroller .alert');
            const alerts = [];

            alertElements.forEach(alert => {
                const alertContent = alert.querySelector('.alert_text')?.textContent?.trim() || '';
                const alertLink = alert.querySelector('a')?.getAttribute('href') || '';
                const alertId = alert.getAttribute('id')?.replace('alert_', '') || '';

                if (alertContent && alertLink) {
                    alerts.push({
                        id: alertId,
                        content: alertContent,
                        link: alertLink,
                        html: alert.innerHTML
                    });
                }
            });

            sendResponse({ alerts });
        } catch (error) {
            console.error('Error parsing HTML:', error);
            sendResponse({ error: error.message });
        }
    }
    return true;
});
